@@ -3,7 +3,6 @@
 import os
 import re
 import sys
-import json
 import pprint
 import textwrap
 import locale
@@ -18,8 +17,6 @@ from xonsh.lazyasd import LazyObject, lazyobject
 from xonsh.codecache import run_script_with_cache
 from xonsh.dirstack import _get_cwd
 from xonsh.events import events
-from xonsh.foreign_shells import load_foreign_envs, load_foreign_aliases
-from xonsh.xontribs import update_context, prompt_xontrib_install
 from xonsh.platform import (
     BASH_COMPLETIONS_DEFAULT, DEFAULT_ENCODING, PATH_DEFAULT,
     ON_WINDOWS, ON_LINUX, os_environ
@@ -47,7 +44,7 @@ import xonsh.prompt.base as prompt
 events.doc('on_envvar_new', """
 on_envvar_new(name: str, value: Any) -> None
 
-Fires after a new enviroment variable is created.
+Fires after a new environment variable is created.
 Note: Setting envvars inside the handler might
 cause a recursion until the limit.
 """)
@@ -56,7 +53,7 @@ cause a recursion until the limit.
 events.doc('on_envvar_change', """
 on_envvar_change(name: str, oldvalue: Any, newvalue: Any) -> None
 
-Fires after an enviroment variable is changed.
+Fires after an environment variable is changed.
 Note: Setting envvars inside the handler might
 cause a recursion until the limit.
 """)
@@ -120,6 +117,7 @@ def DEFAULT_ENSURERS():
     'AUTO_CD': (is_bool, to_bool, bool_to_str),
     'AUTO_PUSHD': (is_bool, to_bool, bool_to_str),
     'AUTO_SUGGEST': (is_bool, to_bool, bool_to_str),
+    'AUTO_SUGGEST_IN_COMPLETIONS': (is_bool, to_bool, bool_to_str),
     'BASH_COMPLETIONS': (is_env_path, str_to_env_path, env_path_to_str),
     'CASE_SENSITIVE_COMPLETIONS': (is_bool, to_bool, bool_to_str),
     re.compile('\w*DIRS$'): (is_env_path, str_to_env_path, env_path_to_str),
@@ -151,7 +149,6 @@ def DEFAULT_ENSURERS():
     'LC_MONETARY': (always_false, locale_convert('LC_MONETARY'), ensure_string),
     'LC_NUMERIC': (always_false, locale_convert('LC_NUMERIC'), ensure_string),
     'LC_TIME': (always_false, locale_convert('LC_TIME'), ensure_string),
-    'LOADED_CONFIG': (is_bool, to_bool, bool_to_str),
     'LOADED_RC_FILES': (is_bool_seq, csv_to_bool_seq, bool_seq_to_csv),
     'MOUSE_SUPPORT': (is_bool, to_bool, bool_to_str),
     'MULTILINE_PROMPT': (is_string_or_callable, ensure_string, ensure_string),
@@ -179,6 +176,7 @@ def DEFAULT_ENSURERS():
     'VIRTUAL_ENV': (is_string, ensure_string, ensure_string),
     'WIN_UNICODE_CONSOLE': (always_false, setup_win_unicode_console, bool_to_str),
     'XONSHRC': (is_env_path, str_to_env_path, env_path_to_str),
+    'XONSH_APPEND_NEWLINE': (is_bool, to_bool, bool_to_str),
     'XONSH_AUTOPAIR': (is_bool, to_bool, bool_to_str),
     'XONSH_CACHE_SCRIPTS': (is_bool, to_bool, bool_to_str),
     'XONSH_CACHE_EVERYTHING': (is_bool, to_bool, bool_to_str),
@@ -234,7 +232,6 @@ def xonsh_config_dir(env):
     return xcd
 
 
-@default_value
 def xonshconfig(env):
     """Ensures and returns the $XONSHCONFIG"""
     xcd = env.get('XONSH_CONFIG_DIR')
@@ -245,16 +242,29 @@ def xonshconfig(env):
 @default_value
 def default_xonshrc(env):
     """Creates a new instance of the default xonshrc tuple."""
+    xcdrc = os.path.join(xonsh_config_dir(env), 'rc.xsh')
     if ON_WINDOWS:
-        dxrc = (xonshconfig(env),
-                os.path.join(os_environ['ALLUSERSPROFILE'],
+        dxrc = (os.path.join(os_environ['ALLUSERSPROFILE'],
                              'xonsh', 'xonshrc'),
+                xcdrc,
                 os.path.expanduser('~/.xonshrc'))
     else:
-        dxrc = (xonshconfig(env), '/etc/xonshrc', os.path.expanduser('~/.xonshrc'))
+        dxrc = ('/etc/xonshrc', xcdrc, os.path.expanduser('~/.xonshrc'))
+    # Check if old config file exists and issue warning
+    old_config_filename = xonshconfig(env)
+    if os.path.isfile(old_config_filename):
+        print('WARNING! old style configuration (' +
+              old_config_filename + ') is no longer supported. ' +
+              'Please migrate to xonshrc.')
     return dxrc
 
 
+@default_value
+def xonsh_append_newline(env):
+    """Appends a newline if we are in interactive mode"""
+    return env.get('XONSH_INTERACTIVE', False)
+
+
 # Default values should generally be immutable, that way if a user wants
 # to set them they have to do a copy and write them to the environment.
 # try to keep this sorted.
@@ -264,6 +274,7 @@ def DEFAULT_VALUES():
         'AUTO_CD': False,
         'AUTO_PUSHD': False,
         'AUTO_SUGGEST': True,
+        'AUTO_SUGGEST_IN_COMPLETIONS': True,
         'BASH_COMPLETIONS': BASH_COMPLETIONS_DEFAULT,
         'CASE_SENSITIVE_COMPLETIONS': ON_LINUX,
         'CDPATH': (),
@@ -293,7 +304,6 @@ def DEFAULT_VALUES():
         'LC_TIME': locale.setlocale(locale.LC_TIME),
         'LC_MONETARY': locale.setlocale(locale.LC_MONETARY),
         'LC_NUMERIC': locale.setlocale(locale.LC_NUMERIC),
-        'LOADED_CONFIG': False,
         'LOADED_RC_FILES': (),
         'MOUSE_SUPPORT': False,
         'MULTILINE_PROMPT': '.',
@@ -323,8 +333,8 @@ def DEFAULT_VALUES():
         'XDG_CONFIG_HOME': os.path.expanduser(os.path.join('~', '.config')),
         'XDG_DATA_HOME': os.path.expanduser(os.path.join('~', '.local',
                                                          'share')),
-        'XONSHCONFIG': xonshconfig,
         'XONSHRC': default_xonshrc,
+        'XONSH_APPEND_NEWLINE': xonsh_append_newline,
         'XONSH_AUTOPAIR': False,
         'XONSH_CACHE_SCRIPTS': True,
         'XONSH_CACHE_EVERYTHING': False,
@@ -392,6 +402,10 @@ def DEFAULT_DOCS():
         'Enable automatic command suggestions based on history, like in the fish '
         'shell.\n\nPressing the right arrow key inserts the currently '
         'displayed suggestion. Only usable with ``$SHELL_TYPE=prompt_toolkit.``'),
+    'AUTO_SUGGEST_IN_COMPLETIONS': VarDocs(
+        'Places the auto-suggest result as the first option in the completions. '
+        'This enables you to tab complete the auto-suggestion.'
+    ),
     'BASH_COMPLETIONS': VarDocs(
         'This is a list (or tuple) of strings that specifies where the '
         '``bash_completion`` script may be found. '
@@ -465,9 +479,8 @@ def DEFAULT_DOCS():
     'FOREIGN_ALIASES_OVERRIDE': VarDocs(
         'Whether or not foreign aliases should override xonsh aliases '
         'with the same name. Note that setting of this must happen in the '
-        'static configuration file '
-        "``$XONSH_CONFIG_DIR/config.json`` in the 'env' section and not in "
-        '``.xonshrc`` as loading of foreign aliases happens before'
+        'environment that xonsh was started from. '
+        "It cannot be set in the ``.xonshrc`` as loading of foreign aliases happens before"
         '``.xonshrc`` is parsed', configurable=True),
     'PROMPT_FIELDS': VarDocs(
         'Dictionary containing variables to be used when formatting $PROMPT '
@@ -499,9 +512,6 @@ def DEFAULT_DOCS():
         'generally replaced by their bright counter parts.',
         configurable=ON_WINDOWS),
     'LANG': VarDocs('Fallback locale setting for systems where it matters'),
-    'LOADED_CONFIG': VarDocs(
-        'Whether or not the xonsh config file was loaded',
-        configurable=False),
     'LOADED_RC_FILES': VarDocs(
         'Whether or not any of the xonsh run control files were loaded at '
         'startup. This is a sequence of bools in Python that is converted '
@@ -521,7 +531,7 @@ def DEFAULT_DOCS():
                       configurable=False),
     'PATH': VarDocs(
         'List of strings representing where to look for executables.'),
-    'PATHEXT': VarDocs('Sequence of extention strings (eg, ``.EXE``) for '
+    'PATHEXT': VarDocs('Sequence of extension strings (eg, ``.EXE``) for '
                        'filtering valid executables by. Each element must be '
                        'uppercase.'),
     'PRETTY_PRINT_RESULTS': VarDocs(
@@ -545,12 +555,12 @@ def DEFAULT_DOCS():
         'The error that is raised is a ``subprocess.CalledProcessError``.'),
     'RIGHT_PROMPT': VarDocs(
         'Template string for right-aligned text '
-        'at the prompt. This may be parameterized in the same way as '
+        'at the prompt. This may be parametrized in the same way as '
         'the ``$PROMPT`` variable. Currently, this is only available in the '
         'prompt-toolkit shell.'),
     'BOTTOM_TOOLBAR': VarDocs(
         'Template string for the bottom toolbar. '
-        'This may be parameterized in the same way as '
+        'This may be parametrized in the same way as '
         'the ``$PROMPT`` variable. Currently, this is only available in the '
         'prompt-toolkit shell.'),
     'SHELL_TYPE': VarDocs(
@@ -580,7 +590,7 @@ def DEFAULT_DOCS():
         'command will be offered as a suggestion.  Also used for "fuzzy" '
         'tab completion of paths.'),
     'SUPPRESS_BRANCH_TIMEOUT_MESSAGE': VarDocs(
-        'Whether or not to supress branch timeout warning messages.'),
+        'Whether or not to suppress branch timeout warning messages.'),
     'TERM': VarDocs(
         'TERM is sometimes set by the terminal emulator. This is used (when '
         "valid) to determine whether or not to set the title. Users shouldn't "
@@ -604,7 +614,7 @@ def DEFAULT_DOCS():
         'Completions display is evaluated and presented whenever a key is '
         'pressed. This avoids the need to press TAB, except to cycle through '
         'the possibilities. This currently only affects the prompt-toolkit shell.'
-        ),
+    ),
     'UPDATE_OS_ENVIRON': VarDocs(
         "If True ``os_environ`` will always be updated "
         "when the xonsh environment changes. The environment can be reset to "
@@ -634,17 +644,16 @@ def DEFAULT_DOCS():
     'XDG_DATA_HOME': VarDocs(
         'Open desktop standard data home dir. This is the same default as '
         'used in the standard.', default="``~/.local/share``"),
-    'XONSHCONFIG': VarDocs(
-        'The location of the static xonsh configuration file, if it exists. '
-        'This is in JSON format.', configurable=False,
-        default="``$XONSH_CONFIG_DIR/config.json``"),
     'XONSHRC': VarDocs(
         'A list of the locations of run control files, if they exist.  User '
         'defined run control file will supersede values set in system-wide '
         'control file if there is a naming collision.', default=(
-            "On Linux & Mac OSX: ``['/etc/xonshrc', '~/.xonshrc']``\n"
+            "On Linux & Mac OSX: ``['/etc/xonshrc', '~/.config/xonsh/rc.xsh', '~/.xonshrc']``\n"
             "\nOn Windows: "
-            "``['%ALLUSERSPROFILE%\\\\xonsh\\\\xonshrc', '~/.xonshrc']``")),
+            "``['%ALLUSERSPROFILE%\\\\xonsh\\\\xonshrc', '~/.config/xonsh/rc.xsh', '~/.xonshrc']``")),
+    'XONSH_APPEND_NEWLINE': VarDocs(
+        'Append new line when a partial line is preserved in output.'
+    ),
     'XONSH_AUTOPAIR': VarDocs(
         'Whether Xonsh will auto-insert matching parentheses, brackets, and '
         'quotes. Only available under the prompt-toolkit shell.'
@@ -664,7 +673,7 @@ def DEFAULT_DOCS():
     'XONSH_DEBUG': VarDocs(
         'Sets the xonsh debugging level. This may be an integer or a boolean. '
         'Setting this variable prior to stating xonsh to ``1`` or ``True`` '
-        'will supress amalgamated imports. Setting it to ``2`` will get some '
+        'will suppress amalgamated imports. Setting it to ``2`` will get some '
         'basic information like input transformation, command replacement. '
         'With ``3`` or a higher number will make more debugging information '
         'presented, like PLY parsing messages.',
@@ -720,7 +729,7 @@ def DEFAULT_DOCS():
         '``True`` if xonsh is running as a login shell, and ``False`` otherwise.',
         configurable=False),
     'XONSH_PROC_FREQUENCY': VarDocs(
-        'The process frquency is the time that '
+        'The process frequency is the time that '
         'xonsh process threads sleep for while running command pipelines. '
         'The value has units of seconds [s].'),
     'XONSH_SHOW_TRACEBACK': VarDocs(
@@ -772,7 +781,7 @@ class Env(cabc.MutableMapping):
 
     * PATH: any variable whose name ends in PATH is a list of strings.
     * XONSH_HISTORY_SIZE: this variable is an (int | float, str) tuple.
-    * LC_* (locale categories): locale catergory names get/set the Python
+    * LC_* (locale categories): locale category names get/set the Python
       locale via locale.getlocale() and locale.setlocale() functions.
 
     An Env instance may be converted to an untyped version suitable for
@@ -794,6 +803,10 @@ class Env(cabc.MutableMapping):
             args = (os_environ,)
         for key, val in dict(*args, **kwargs).items():
             self[key] = val
+        if ON_WINDOWS:
+            path_key = next((k for k in self._d if k.upper() == 'PATH'), None)
+            if path_key:
+                self['PATH'] = self._d.pop(path_key)
         if 'PATH' not in self._d:
             # this is here so the PATH is accessible to subprocs and so that
             # it can be modified in-place in the xonshrc file
@@ -827,7 +840,7 @@ class Env(cabc.MutableMapping):
 
     def replace_env(self):
         """Replaces the contents of os_environ with a detyped version
-        of the xonsh environement.
+        of the xonsh environment.
         """
         if self._orig_env is None:
             self._orig_env = dict(os_environ)
@@ -836,7 +849,7 @@ class Env(cabc.MutableMapping):
 
     def undo_replace_env(self):
         """Replaces the contents of os_environ with a detyped version
-        of the xonsh environement.
+        of the xonsh environment.
         """
         if self._orig_env is not None:
             os_environ.clear()
@@ -870,7 +883,7 @@ class Env(cabc.MutableMapping):
         return vd
 
     def help(self, key):
-        """Get information about a specific enviroment variable."""
+        """Get information about a specific environment variable."""
         vardocs = self.get_docs(key)
         width = min(79, os.get_terminal_size()[0])
         docstr = '\n'.join(textwrap.wrap(vardocs.docstr, width=width))
@@ -1036,54 +1049,6 @@ BASE_ENV = LazyObject(lambda: {
 }, globals(), 'BASE_ENV')
 
 
-def load_static_config(ctx, config=None):
-    """Loads a static configuration file from a given context, rather than the
-    current environment.  Optionally may pass in configuration file name.
-    """
-    env = {}
-    env['XDG_CONFIG_HOME'] = ctx.get('XDG_CONFIG_HOME',
-                                     DEFAULT_VALUES['XDG_CONFIG_HOME'])
-    env['XONSH_CONFIG_DIR'] = ctx['XONSH_CONFIG_DIR'] if 'XONSH_CONFIG_DIR' in ctx \
-        else xonsh_config_dir(env)
-    if config is not None:
-        env['XONSHCONFIG'] = ctx['XONSHCONFIG'] = config
-    elif 'XONSHCONFIG' in ctx:
-        config = env['XONSHCONFIG'] = ctx['XONSHCONFIG']
-    else:
-        # don't set in ctx in order to maintain default
-        config = env['XONSHCONFIG'] = xonshconfig(env)
-    if os.path.isfile(config):
-        # Note that an Env instance at __xonsh_env__ has not been started yet,
-        # per se, so we have to use os_environ
-        encoding = os_environ.get('XONSH_ENCODING',
-                                  DEFAULT_VALUES.get('XONSH_ENCODING', 'utf8'))
-        errors = os_environ.get('XONSH_ENCODING_ERRORS',
-                                DEFAULT_VALUES.get('XONSH_ENCODING_ERRORS',
-                                                   'surrogateescape'))
-        with open(config, 'r', encoding=encoding, errors=errors) as f:
-            try:
-                conf = json.load(f)
-                assert isinstance(conf, cabc.Mapping)
-                ctx['LOADED_CONFIG'] = True
-            except Exception as e:
-                conf = {}
-                ctx['LOADED_CONFIG'] = False
-                print_exception()
-                # JSONDecodeError was added in Python v3.5
-                jerr = json.JSONDecodeError \
-                    if hasattr(json, 'JSONDecodeError') else ValueError
-                if isinstance(e, jerr):
-                    msg = 'Xonsh config file is not valid JSON.'
-                else:
-                    msg = 'Could not load xonsh config.'
-                print(msg, file=sys.stderr)
-    else:
-        conf = {}
-        ctx['LOADED_CONFIG'] = False
-    builtins.__xonsh_config__ = conf
-    return conf
-
-
 def xonshrc_context(rcfiles=None, execer=None, ctx=None, env=None, login=True):
     """Attempts to read in all xonshrc files and return the context."""
     loaded = env['LOADED_RC_FILES'] = []
@@ -1096,12 +1061,8 @@ def xonshrc_context(rcfiles=None, execer=None, ctx=None, env=None, login=True):
             loaded.append(False)
             continue
         _, ext = os.path.splitext(rcfile)
-        if ext == '.json':
-            status = static_config_run_control(rcfile, ctx, env, execer=execer,
-                                               login=login)
-        else:
-            status = xonsh_script_run_control(rcfile, ctx, env, execer=execer,
-                                              login=login)
+        status = xonsh_script_run_control(rcfile, ctx, env, execer=execer,
+                                          login=login)
         loaded.append(status)
     return ctx
 
@@ -1129,41 +1090,6 @@ def foreign_env_fixes(ctx):
         del ctx['PROMPT']
 
 
-def static_config_run_control(filename, ctx, env, execer=None, login=True):
-    """Loads a static config file and applies it as a run control."""
-    if not login:
-        return
-    conf = load_static_config(env, config=filename)
-    # load foreign shells
-    foreign_env = load_foreign_envs(shells=conf.get('foreign_shells', ()),
-                                    issue_warning=False)
-    if ON_WINDOWS:
-        windows_foreign_env_fixes(foreign_env)
-    foreign_env_fixes(foreign_env)
-    env.update(foreign_env)
-    aliases = builtins.aliases
-    foreign_aliases = load_foreign_aliases(config=filename, issue_warning=True)
-    for k, v in foreign_aliases.items():
-        if k in aliases:
-            msg = ('Skipping application of {0!r} alias from foreign shell '
-                   '(loaded from {1!r}) since it shares a name with an '
-                   'existing xonsh alias.')
-            print(msg.format(k, filename))
-        else:
-            aliases[k] = v
-    # load xontribs
-    names = conf.get('xontribs', ())
-    for name in names:
-        update_context(name, ctx=ctx)
-    if getattr(update_context, 'bad_imports', None):
-        prompt_xontrib_install(update_context.bad_imports)
-        del update_context.bad_imports
-    # Do static config environment last, to allow user to override any of
-    # our environment choices
-    env.update(conf.get('env', ()))
-    return True
-
-
 def xonsh_script_run_control(filename, ctx, env, execer=None, login=True):
     """Loads a xonsh file and applies it as a run control."""
     if execer is None:
@@ -1190,6 +1116,9 @@ def default_env(env=None):
     ctx = dict(BASE_ENV)
     ctx.update(os_environ)
     ctx['PWD'] = _get_cwd() or ''
+    # These can cause problems for programs (#2543)
+    ctx.pop('LINES', None)
+    ctx.pop('COLUMNS', None)
     # other shells' PROMPT definitions generally don't work in XONSH:
     try:
         del ctx['PROMPT']
