@@ -9,7 +9,7 @@ import collections.abc as cabc
 from xonsh.ast import CtxAwareTransformer
 from xonsh.parser import Parser
 from xonsh.tools import (subproc_toks, find_next_break, get_logical_line,
-                         replace_logical_line)
+                         replace_logical_line, balanced_parens)
 from xonsh.built_ins import load_builtins, unload_builtins
 
 
@@ -65,7 +65,7 @@ class Execer(object):
         # Parsing actually happens in a couple of phases. The first is a
         # shortcut for a context-free parser. Normally, all subprocess
         # lines should be wrapped in $(), to indicate that they are a
-        # subproc. But that would be super annoying. Unfortnately, Python
+        # subproc. But that would be super annoying. Unfortunately, Python
         # mode - after indentation - is whitespace agnostic while, using
         # the Python token, subproc mode is whitespace aware. That is to say,
         # in Python mode "ls -l", "ls-l", and "ls - l" all parse to the
@@ -181,22 +181,22 @@ class Execer(object):
                 last_error_line = e.loc.lineno
                 idx = last_error_line - 1
                 lines = input.splitlines()
-                line, nlogical = get_logical_line(lines, idx)
+                line, nlogical, idx = get_logical_line(lines, idx)
                 if input.endswith('\n'):
                     lines.append('')
                 if len(line.strip()) == 0:
                     # whitespace only lines are not valid syntax in Python's
                     # interactive mode='single', who knew?! Just ignore them.
-                    # this might cause actual sytax errors to have bad line
+                    # this might cause actual syntax errors to have bad line
                     # numbers reported, but should only affect interactive mode
                     del lines[idx]
                     last_error_line = last_error_col = -1
                     input = '\n'.join(lines)
                     continue
 
-                if last_error_line > 1 and lines[idx-1].rstrip()[-1:] == ':':
+                if last_error_line > 1 and lines[idx - 1].rstrip()[-1:] == ':':
                     # catch non-indented blocks and raise error.
-                    prev_indent = len(lines[idx-1]) - len(lines[idx-1].lstrip())
+                    prev_indent = len(lines[idx - 1]) - len(lines[idx - 1].lstrip())
                     curr_indent = len(lines[idx]) - len(lines[idx].lstrip())
                     if prev_indent == curr_indent:
                         raise original_error
@@ -208,8 +208,9 @@ class Execer(object):
                     # go greedy the first time if the syntax error was because
                     # we hit an end token out of place. This usually indicates
                     # a subshell or maybe a macro.
-                    greedy = True
-                    maxcol = None
+                    if not balanced_parens(line, maxcol=maxcol):
+                        greedy = True
+                        maxcol = None
                 sbpline = subproc_toks(line, returnline=True, greedy=greedy,
                                        maxcol=maxcol, lexer=lexer)
                 if sbpline is None:
