@@ -24,6 +24,7 @@ import codecs
 import builtins
 import itertools
 import collections
+import token
 from token import (AMPER, AMPEREQUAL, AT, CIRCUMFLEX,
                    CIRCUMFLEXEQUAL, COLON, COMMA, DEDENT, DOT, DOUBLESLASH,
                    DOUBLESLASHEQUAL, DOUBLESTAR, DOUBLESTAREQUAL, ENDMARKER, EQEQUAL,
@@ -46,22 +47,24 @@ blank_re = LazyObject(lambda: re.compile(br'^[ \t\f]*(?:[#\r\n]|$)', re.ASCII),
 #
 # token modifications
 #
-import token
-
+tok_name = tok_name.copy()
 __all__ = token.__all__ + ["COMMENT", "tokenize", "detect_encoding",
                            "NL", "untokenize", "ENCODING", "TokenInfo",
                            "TokenError", 'SEARCHPATH', 'ATDOLLAR', 'ATEQUAL',
                            'DOLLARNAME', 'IOREDIRECT']
-PY35 = PYTHON_VERSION_INFO >= (3, 5, 0)
-if PY35:
+HAS_ASYNC = (3, 5, 0) <= PYTHON_VERSION_INFO < (3, 7, 0)
+if HAS_ASYNC:
     ASYNC = token.ASYNC
     AWAIT = token.AWAIT
-    AUGASSIGN_OPS = r"[+\-*/%&@|^=<>]=?"
     ADDSPACE_TOKS = (NAME, NUMBER, ASYNC, AWAIT)
 else:
-    AUGASSIGN_OPS = r"[+\-*/%&|^=<>]=?"
     ADDSPACE_TOKS = (NAME, NUMBER)
 del token  # must clean up token
+PY35 = (3, 5, 0) <= PYTHON_VERSION_INFO
+AUGASSIGN_OPS = r"[+\-*/%&@|^=<>]=?"
+if not PY35:
+    AUGASSIGN_OPS = AUGASSIGN_OPS.replace('@', '')
+
 
 COMMENT = N_TOKENS
 tok_name[COMMENT] = 'COMMENT'
@@ -193,19 +196,20 @@ Comment = r'#[^\r\n]*'
 Ignore = Whitespace + tokany(r'\\\r?\n' + Whitespace) + maybe(Comment)
 Name_RE = r'\$?\w+'
 
-Hexnumber = r'0[xX][0-9a-fA-F]+'
-Binnumber = r'0[bB][01]+'
-Octnumber = r'0[oO][0-7]+'
-Decnumber = r'(?:0+|[1-9][0-9]*)'
+Hexnumber = r'0[xX](?:_?[0-9a-fA-F])+'
+Binnumber = r'0[bB](?:_?[01])+'
+Octnumber = r'0[oO](?:_?[0-7])+'
+Decnumber = r'(?:0(?:_?0)*|[1-9](?:_?[0-9])*)'
 Intnumber = group(Hexnumber, Binnumber, Octnumber, Decnumber)
-Exponent = r'[eE][-+]?[0-9]+'
-Pointfloat = group(r'[0-9]+\.[0-9]*', r'\.[0-9]+') + maybe(Exponent)
-Expfloat = r'[0-9]+' + Exponent
+Exponent = r'[eE][-+]?[0-9](?:_?[0-9])*'
+Pointfloat = group(r'[0-9](?:_?[0-9])*\.(?:[0-9](?:_?[0-9])*)?',
+                   r'\.[0-9](?:_?[0-9])*') + maybe(Exponent)
+Expfloat = r'[0-9](?:_?[0-9])*' + Exponent
 Floatnumber = group(Pointfloat, Expfloat)
-Imagnumber = group(r'[0-9]+[jJ]', Floatnumber + r'[jJ]')
+Imagnumber = group(r'[0-9](?:_?[0-9])*[jJ]', Floatnumber + r'[jJ]')
 Number = group(Imagnumber, Floatnumber, Intnumber)
 
-StringPrefix = r'(?:[bBp][rR]?|[rR][bBp]?|[uU])?'
+StringPrefix = r'(?:[bBp][rR]?|[rR][bBpfF]?|[uU]|[fF][rR]?)?'
 
 # Tail end of ' string.
 Single = r"[^'\\]*(?:\\.[^'\\]*)*'"
@@ -234,7 +238,7 @@ _redir_map = (
     # stdout to stderr
     'out>err', 'out>&2', '1>err', 'out>e', 'out>2', 'o>err', 'o>&2',
     '1>&2', 'o>e', '1>e', 'o>2', '1>2',
-    )
+)
 IORedirect = group(group(*_redir_map), '{}>>?'.format(group(*_redir_names)))
 _redir_check = set(_redir_map)
 _redir_check = {'{}>'.format(i) for i in _redir_names}.union(_redir_check)
@@ -268,16 +272,23 @@ endpats = {"'": Single, '"': Double,
            "'''": Single3, '"""': Double3,
            "r'''": Single3, 'r"""': Double3,
            "b'''": Single3, 'b"""': Double3,
+           "f'''": Single3, 'f"""': Double3,
            "R'''": Single3, 'R"""': Double3,
            "B'''": Single3, 'B"""': Double3,
+           "F'''": Single3, 'F"""': Double3,
            "br'''": Single3, 'br"""': Double3,
+           "fr'''": Single3, 'fr"""': Double3,
            "bR'''": Single3, 'bR"""': Double3,
            "Br'''": Single3, 'Br"""': Double3,
            "BR'''": Single3, 'BR"""': Double3,
            "rb'''": Single3, 'rb"""': Double3,
+           "rf'''": Single3, 'rf"""': Double3,
            "Rb'''": Single3, 'Rb"""': Double3,
+           "Fr'''": Single3, 'Fr"""': Double3,
            "rB'''": Single3, 'rB"""': Double3,
+           "rF'''": Single3, 'rF"""': Double3,
            "RB'''": Single3, 'RB"""': Double3,
+           "RF'''": Single3, 'RF"""': Double3,
            "u'''": Single3, 'u"""': Double3,
            "U'''": Single3, 'U"""': Double3,
            "p'''": Single3, 'p"""': Double3,
@@ -286,16 +297,22 @@ endpats = {"'": Single, '"': Double,
            "rp'''": Single3, 'rp"""': Double3,
            "Rp'''": Single3, 'Rp"""': Double3,
            'r': None, 'R': None, 'b': None, 'B': None,
-           'u': None, 'U': None, 'p': None}
+           'u': None, 'U': None, 'p': None, 'f': None,
+           'F': None}
 
 triple_quoted = {}
 for t in ("'''", '"""',
           "r'''", 'r"""', "R'''", 'R"""',
           "b'''", 'b"""', "B'''", 'B"""',
+          "f'''", 'f"""', "F'''", 'F"""',
           "br'''", 'br"""', "Br'''", 'Br"""',
           "bR'''", 'bR"""', "BR'''", 'BR"""',
           "rb'''", 'rb"""', "rB'''", 'rB"""',
           "Rb'''", 'Rb"""', "RB'''", 'RB"""',
+          "fr'''", 'fr"""', "Fr'''", 'Fr"""',
+          "fR'''", 'fR"""', "FR'''", 'FR"""',
+          "rf'''", 'rf"""', "rF'''", 'rF"""',
+          "Rf'''", 'Rf"""', "RF'''", 'RF"""',
           "u'''", 'u"""', "U'''", 'U"""',
           "p'''", 'p""""', "pr'''", 'pr""""',
           "pR'''", 'pR""""', "rp'''", 'rp""""',
@@ -306,10 +323,15 @@ single_quoted = {}
 for t in ("'", '"',
           "r'", 'r"', "R'", 'R"',
           "b'", 'b"', "B'", 'B"',
+          "f'", 'f"', "F'", 'F"',
           "br'", 'br"', "Br'", 'Br"',
           "bR'", 'bR"', "BR'", 'BR"',
           "rb'", 'rb"', "rB'", 'rB"',
           "Rb'", 'Rb"', "RB'", 'RB"',
+          "fr'", 'fr"', "Fr'", 'Fr"',
+          "fR'", 'fR"', "FR'", 'FR"',
+          "rf'", 'rf"', "rF'", 'rF"',
+          "Rf'", 'Rf"', "RF'", 'RF"',
           "u'", 'u"', "U'", 'U"',
           "p'", 'p"', "pr'", 'pr"',
           "pR'", 'pR"', "rp'", 'rp"',
@@ -768,7 +790,11 @@ def _tokenize(readline, encoding):
                         stashed = None
 
                     yield tok
+                elif token == '\\\n' or token == '\\\r\n':  # continued stmt
+                    continued = 1
+                    yield TokenInfo(ERRORTOKEN, token, spos, epos, line)
                 elif initial == '\\':  # continued stmt
+                    # for cases like C:\\path\\to\\file
                     continued = 1
                 else:
                     if initial in '([{':
@@ -797,7 +823,7 @@ def _tokenize(readline, encoding):
 
 def tokenize(readline):
     """
-    The tokenize() generator requires one argment, readline, which
+    The tokenize() generator requires one argument, readline, which
     must be a callable object which provides the same interface as the
     readline() method of built-in file objects.  Each call to the function
     should return one line of input as bytes.  Alternately, readline
