@@ -165,8 +165,8 @@ class EnvPath(collections.MutableSequence):
                     # make TypeError's message as informative as possible
                     # when given an invalid initialization sequence
                     raise TypeError(
-                            "EnvPath's initialization sequence should only "
-                            "contain str, bytes and pathlib.Path entries")
+                        "EnvPath's initialization sequence should only "
+                        "contain str, bytes and pathlib.Path entries")
                 self._l = args
             else:
                 raise TypeError('EnvPath cannot be initialized with items '
@@ -228,6 +228,36 @@ class EnvPath(collections.MutableSequence):
             other = other._l
         return EnvPath(other + self._l)
 
+    def add(self, data, front=False, replace=False):
+        """Add a value to this EnvPath,
+
+        path.add(data, front=bool, replace=bool) -> ensures that path contains data, with position determined by kwargs
+
+        Parameters
+        ----------
+        data : string or bytes or pathlib.Path
+            value to be added
+        front : bool
+            whether the value should be added to the front, will be
+            ignored if the data already exists in this EnvPath and
+            replace is False
+            Default : False
+        replace : bool
+            If True, the value will be removed and added to the
+            start or end(depending on the value of front)
+            Default : False
+
+        Returns
+        -------
+        None
+
+        """
+        if data not in self._l:
+            self._l.insert(0 if front else len(self._l), data)
+        elif replace:
+            self._l.remove(data)
+            self._l.insert(0 if front else len(self._l), data)
+
 
 class DefaultNotGivenType(object):
     """Singleton for representing when no default value is given."""
@@ -242,9 +272,8 @@ class DefaultNotGivenType(object):
 
 DefaultNotGiven = DefaultNotGivenType()
 
-BEG_TOK_SKIPS = LazyObject(
-                    lambda: frozenset(['WS', 'INDENT', 'NOT', 'LPAREN']),
-                    globals(), 'BEG_TOK_SKIPS')
+BEG_TOK_SKIPS = LazyObject(lambda: frozenset(['WS', 'INDENT', 'NOT', 'LPAREN']),
+                           globals(), 'BEG_TOK_SKIPS')
 END_TOK_TYPES = LazyObject(lambda: frozenset(['SEMI', 'AND', 'OR', 'RPAREN']),
                            globals(), 'END_TOK_TYPES')
 RE_END_TOKS = LazyObject(lambda: re.compile('(;|and|\&\&|or|\|\||\))'),
@@ -469,7 +498,7 @@ def get_logical_line(lines, idx):
     n = 1
     nlines = len(lines)
     linecont = get_line_continuation()
-    while idx > 0 and lines[idx-1].endswith(linecont):
+    while idx > 0 and lines[idx - 1].endswith(linecont):
         idx -= 1
     start = idx
     line = lines[idx]
@@ -494,9 +523,9 @@ def replace_logical_line(lines, logical, idx, n):
         lines[idx] = logical
         return
     space = ' '
-    for i in range(idx, idx+n-1):
+    for i in range(idx, idx + n - 1):
         a = len(lines[i])
-        b = logical.find(space, a-1)
+        b = logical.find(space, a - 1)
         if b < 0:
             # no space found
             lines[i] = logical
@@ -505,7 +534,7 @@ def replace_logical_line(lines, logical, idx, n):
             # found space to split on
             lines[i] = logical[:b] + linecont
             logical = logical[b:]
-    lines[idx+n-1] = logical
+    lines[idx + n - 1] = logical
 
 
 def is_balanced(expr, ltok, rtok):
@@ -842,12 +871,14 @@ def print_exception(msg=None):
         sys.stderr.write(msg)
 
 
-def display_error_message():
+def display_error_message(strip_xonsh_error_types=True):
     """
     Prints the error message of the current exception on stderr.
     """
     exc_type, exc_value, exc_traceback = sys.exc_info()
     exception_only = traceback.format_exception_only(exc_type, exc_value)
+    if exc_type is XonshError and strip_xonsh_error_types:
+        exception_only[0] = exception_only[0].partition(': ')[-1]
     sys.stderr.write(''.join(exception_only))
 
 
@@ -1436,7 +1467,7 @@ HISTORY_UNITS = LazyObject(lambda: {
     'tb': ('b', _tb_to_b),
     'terabyte': ('b', _tb_to_b),
     'terabytes': ('b', _tb_to_b),
-    }, globals(), 'HISTORY_UNITS')
+}, globals(), 'HISTORY_UNITS')
 """Maps lowercase unit names to canonical name and conversion utilities."""
 
 
@@ -1676,7 +1707,7 @@ RE_STRING_CONT = LazyDict({
     "'": lambda: re.compile(r"((\\(.|\n))|([^'\\]))*"),
     '"""': lambda: re.compile(r'((\\(.|\n))|([^"\\])|("(?!""))|\n)*'),
     "'''": lambda: re.compile(r"((\\(.|\n))|([^'\\])|('(?!''))|\n)*"),
-    }, globals(), 'RE_STRING_CONT')
+}, globals(), 'RE_STRING_CONT')
 """Dictionary mapping starting quote sequences to regular expressions that
 match the contents of a string beginning with those quotes (not including the
 terminating quotes)"""
@@ -1923,18 +1954,27 @@ def columnize(elems, width=80, newline='\n'):
     The newline character will be appended to the end of each line.
     """
     sizes = [len(e) + 1 for e in elems]
+    total = sum(sizes)
     nelem = len(elems)
-    ncols = 1
-    nrows = len(sizes)
-    columns = [sizes]
-    last_longest_row = max(sizes)
-    while True:
+    if total - 1 <= width:
+        ncols = len(sizes)
+        nrows = 1
+        columns = [sizes]
+        last_longest_row = total
+        enter_loop = False
+    else:
+        ncols = 1
+        nrows = len(sizes)
+        columns = [sizes]
+        last_longest_row = max(sizes)
+        enter_loop = True
+    while enter_loop:
         longest_row = sum(map(max, columns))
         if longest_row - 1 <= width:
             # we might be able to fit another column.
             ncols += 1
             nrows = nelem // ncols
-            columns = [sizes[i*nrows:(i+1)*nrows] for i in range(ncols)]
+            columns = [sizes[i * nrows:(i + 1) * nrows] for i in range(ncols)]
             last_longest_row = longest_row
         else:
             # we can't fit another column
@@ -1943,7 +1983,7 @@ def columnize(elems, width=80, newline='\n'):
             break
     pad = (width - last_longest_row + ncols) // ncols
     pad = pad if pad > 1 else 1
-    data = [elems[i*nrows:(i+1)*nrows] for i in range(ncols)]
+    data = [elems[i * nrows:(i + 1) * nrows] for i in range(ncols)]
     colwidths = [max(map(len, d)) + pad for d in data]
     colwidths[-1] -= pad
     row_t = ''.join(['{{row[{i}]: <{{w[{i}]}}}}'.format(i=i) for i in range(ncols)])
